@@ -1,16 +1,10 @@
 from flask import Flask, jsonify
 from flask_socketio import SocketIO
 import json
+import pkgutil
 
-import os
-
-path = os.path.relpath(__file__)
-dir = os.path.dirname(path)
-
-print(f"rel path is {path} and dir is {dir}")
-
-with open(f"data.json", 'r') as f:
-    data = f.read()
+data = pkgutil.get_data(__package__, 'data.json')
+data = json.loads(data)
 
 app = Flask('serverC')
 sio = SocketIO(app)
